@@ -59,8 +59,12 @@ def get_things():
         cmd = ["cat",  "/usr/share/i18n/SUPPORTED"]
     else:
         cmd = ["locale",  "-a"]
-    for thing in Popen(cmd, stdout=PIPE).communicate()[0].split("\n"):
-        myarr.append(thing.split(".")[0].split(" ")[0])
+    for thing in Popen(cmd, stdout=PIPE).stdout.readlines():
+        try:
+            thing=str(thing.decode("utf-8").strip())
+            myarr.append(thing.split(".")[0].split(" ")[0])
+        except UnicodeDecodeError:
+            pass
     return myarr
 
 def nice_name(my_locale):
@@ -104,7 +108,7 @@ if __name__ == "__main__":
         try:
             this_nice_name = nice_name(my_locale)
             if len(this_nice_name) > 0 and this_nice_name != my_locale:
-                print my_locale + " " + this_nice_name
+                print(my_locale + " " + this_nice_name)
         except UnicodeEncodeError:
             sys.stderr.write('unicode error encountered, skipping locale: ' + my_locale + '\n')
         except UnicodeDecodeError:
